summaryrefslogtreecommitdiffstats
path: root/ConfigureChecks.cmake
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2021-11-16 00:33:12 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2021-11-16 00:33:12 +0900
commita8e9f8dd80bddc39a64cd807880b5630fb9efec7 (patch)
tree866a00fc55bdfada1dd3d46c61feb1440d960526 /ConfigureChecks.cmake
parent98b37ff3b1d307add5fe3f9e1f9c7923831debd4 (diff)
downloadpolkit-tqt-a8e9f8dd80bddc39a64cd807880b5630fb9efec7.tar.gz
polkit-tqt-a8e9f8dd80bddc39a64cd807880b5630fb9efec7.zip
Conversion of 'agent' library module.
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'ConfigureChecks.cmake')
-rw-r--r--ConfigureChecks.cmake14
1 files changed, 10 insertions, 4 deletions
diff --git a/ConfigureChecks.cmake b/ConfigureChecks.cmake
index ff4dd3360..0d7047c52 100644
--- a/ConfigureChecks.cmake
+++ b/ConfigureChecks.cmake
@@ -22,10 +22,16 @@ tde_setup_largefiles( )
# tqt
find_package( TQt )
-# check for polkit
-pkg_search_module( POLKIT polkit-gobject-1 )
-if( NOT POLKIT_FOUND )
- tde_message_fatal( "polkit is required, but was not found on your system" )
+# check for polkit-gobject-1
+pkg_search_module( POLKIT_GOBJECT polkit-gobject-1 )
+if( NOT POLKIT_GOBJECT_FOUND )
+ tde_message_fatal( "polkit-gobject-1 is required, but was not found on your system" )
+endif( )
+
+# check for polkit-agent-1
+pkg_search_module( POLKIT_AGENT polkit-agent-1 )
+if( NOT POLKIT_AGENT_FOUND )
+ tde_message_fatal( "polkit-agent-1 is required, but was not found on your system" )
endif( )
# gcc visibility